@@ -477,8 +477,11 @@ class StickProtocol():
                 senderKeys.append(key)
             bundle['senderKeys'] = senderKeys
             user.save()
-            if not self.Device.objects.filter(user=user, deviceId=data['deviceId']).exists():
+            device = self.Device.objects.filter(user=user, deviceId=data['deviceId']).first()
+            if not device:
                 self.Device.objects.create(user=user, deviceId=data['deviceId'], name=data['deviceName'], chatId=uuid.uuid4())
+            else:
+                device.chatId = uuid.uuid4()
             return {"bundle": bundle, "verify": True}
         else:
             return {"verify": False}
